@@ -234,8 +234,7 @@ void quiche_config_set_initial_congestion_window_packets(quiche_config *config,
 enum quiche_cc_algorithm {
     QUICHE_CC_RENO = 0,
     QUICHE_CC_CUBIC = 1,
-    QUICHE_CC_BBR = 2,
-    QUICHE_CC_BBR2 = 3,
+    QUICHE_CC_BBR2_GCONGESTION = 4,
 };
 
 // Sets the congestion control algorithm used.
@@ -420,7 +419,7 @@ int quiche_conn_stream_shutdown(quiche_conn *conn, uint64_t stream_id,
                                 enum quiche_shutdown direction, uint64_t err);
 
 // Returns the stream's send capacity in bytes.
-ssize_t quiche_conn_stream_capacity(const quiche_conn *conn, uint64_t stream_id);
+ssize_t quiche_conn_stream_capacity(quiche_conn *conn, uint64_t stream_id);
 
 // Returns true if the stream has data that can be read.
 bool quiche_conn_stream_readable(const quiche_conn *conn, uint64_t stream_id);
